# Changelog

## 0.0.9 (2023-09-26)

#### Docs

* Updating release procedure.
#### Others

* Globally reformatted sources.

Full set of changes: [`0.0.8...0.0.9`](https://github.com/kev-m/pyCoilGen/compare/0.0.8...0.0.9)

## 0.0.8 (2023-09-25)

#### New Features

* Initial release candidate.
